package main

type PlanetType uint8

const ( // Production: The Ratio is 1:X where X is the number of population designated
	EarthLike PlanetType = iota // Production: Ore=1:6, Org=1:5, Equ=1:8, Fig=1:10, Shields=1:25
	Mountain                    // Production: Ore=1:4, Org=1:8, Equ=1:6, Fig=1:7, Shields=1:20
	Ocean                       // Production: Ore=1:8, Org=1:3, Equ=1:6, Fig=1:4, Shields=1:28
	Volcanic                    // Production: Ore=NA, Org=NA, Equ=NA, Fig=NA, Shields=NA
	Glacial                     // Production: Ore=1:7, Org=NA, Equ=1:7, Fig=1:12, Shields=1:30
)

type Planet struct {
	ID               ID
	Name             string
	Owner            ID
	CorpOwned        bool
	Type             PlanetType
	CitadelLvl       uint16 // Lvl1 Unlocks Fighter Defense and Bank, Lvl2 Unlocks Planetary Cannon, Lvl3 Unlocks Production for Shields, Lvl4 Unlocks Teleport and TeleportShip, Lvl5 Unlocks Warp
	TeleportDist     uint64 // Beam the player to another ship
	TeleportShipDist uint64 // Beam the player in the current ship
	WarpDist         uint64 // Move the planet
	Credits          uint64
	Shields          uint64
	// Planetary Cannon Settings
	CannonSector  uint8 // Percentage of fuel Ore too consume per shot when a non-corp or hostile ship enters the sector (1 ore to 5 damage)
	CannonLanding uint8 // Percentage of fuel Ore too consume per shot when a non-corp or hostile ship attempts to land on the planet (1 ore to 10 damage)
	// Planetary Defense (Fighter) Settings
	FighterLanding uint8 // Percentage of fighters too attack a non-corp or hostile ship when they attempt to land on the planet (fighter odds 1:2, essentially double damage)
	// Inventory
	Population uint64 // Population in supposed 1,000s
	Ore        uint64 // Per Ton
	MaxOre     uint64
	Org        uint64
	MaxOrg     uint64
	Equ        uint64
	MaxEqu     uint64
	Fighters   uint64 // Per Unit
	// Production Settings
	ProductOre uint64 // Population placed for fuel Ore production (based on planet type)
	ProductOrg uint64 // Organics production
	ProductEqu uint64 // Equipment production
}
